@@ -1,4 +1,4 @@
-/* $Id: syntab.h,v 1.12 2003/04/21 19:53:34 phil Exp $ */
+/* $Id: syntab.h,v 1.14 2020-10-17 20:06:14 phil Exp $ */
 
 enum action { AC_CONTIN, AC_STOP, AC_STOPSH, AC_ERROR, AC_GOTO };
 
@@ -10,7 +10,7 @@ struct acts {
 
 #define CHARSET 256			/* XXX */
 struct syntab {
-    char *name;				/* table name */
+    const char *name;			/* table name */
     char chrs[CHARSET];			/* index into actions */
     /* XXX include count of entries in actions array? */
     const struct acts *actions;		/* pointer to action table */
@@ -23,7 +23,7 @@ enum stream_ret {
 };
 
 /* from lib/stream.c */
-enum stream_ret stream __P((struct spec *,struct spec *,struct syntab *));
-void clertb __P((struct syntab *,enum action));
-void plugtb __P((struct syntab *,enum action,struct spec *));
-int any __P((struct spec *,struct descr *));
+enum stream_ret stream(struct spec *,struct spec *,struct syntab *);
+void clertb(struct syntab *,enum action);
+void plugtb(struct syntab *,enum action,struct spec *);
+int any(struct spec *,struct descr *);
