@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.4 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.5 2020-09-27 22:41:02 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -24,7 +24,7 @@
 #endif /* CLK_TCK not defined */
 
 real_t
-mstime() {
+mstime(void) {
     clock_t t;
     int ticks;
 
