@@ -1,4 +1,4 @@
-/* $Id: spcint.c,v 1.9 2004/02/03 05:37:19 phil Exp $ */
+/* $Id: spcint.c,v 1.13 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * convert from strings to integer using strtol
@@ -9,9 +9,7 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
-#ifdef HAVE_STDLIB_H			/* before stdio */
 #include <stdlib.h>
-#endif /* HAVE_STDLIB_H defined */
 #include <stdio.h>
 #include <errno.h>
 
@@ -25,17 +23,10 @@
 #include "res.h"
 #include "data.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 int
-spcint(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
+spcint(struct descr *dp, struct spec *sp) {
     char buffer[64];			/* ??? */
-    int_t len;
+    size_t len;
     char *cp;
     int_t temp;
 
@@ -52,7 +43,7 @@ spcint(dp, sp)
 
     if (len > sizeof(buffer)-1)
 	len = sizeof(buffer)-1;
-    bcopy( cp, buffer, len );
+    memcpy(buffer, cp, len);
     buffer[len] = '\0';
 
     errno = 0;
