@@ -1,4 +1,4 @@
-/* $Id: spreal.c,v 1.6 2003/04/22 00:58:23 phil Exp $ */
+/* $Id: spreal.c,v 1.12 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * convert from string to real using strtod
@@ -10,6 +10,7 @@
 #endif /* HAVE_CONFIG_H defined */
 
 #include <stdio.h>
+#include <stdlib.h>			/* strtod */
 
 #include "h.h"
 #include "snotypes.h"
@@ -21,20 +22,12 @@
 #include "res.h"
 #include "data.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 int
-spreal(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
+spreal(struct descr *dp, struct spec *sp) {
     char buffer[64];			/* ??? */
-    int len;
+    size_t len;
     char *cp;
-    float temp;
-    double strtod();
+    real_t temp;
 
     len = S_L(sp);
     cp = S_SP(sp);
@@ -49,7 +42,7 @@ spreal(dp, sp)
 
     if (len > sizeof(buffer)-1)
 	len = sizeof(buffer)-1;
-    bcopy( cp, buffer, len );
+    memcpy(buffer, cp, len );
     buffer[len] = '\0';
 
     temp = strtod( buffer, &cp );
