@@ -1,4 +1,4 @@
-/* $Id: bzero.c,v 1.3 2001/12/03 01:14:42 phil Exp $ */
+/* $Id: bzero.c,v 1.4 2020-09-27 22:06:16 phil Exp $ */
 
 /*
  * fancy generic bzero
@@ -27,10 +27,7 @@ typedef long word_t;
  */
 
 void
-bzero(cp, length)
-    register char *cp;
-    size_t length;
-{
+bzero(register char *cp, size_t length) {
     if (length >= 2*WSIZE) {		/* enough to bother? */
 	register word_t *wp;
 	register size_t t;
