@@ -1,4 +1,4 @@
-/* $Id: bal.c,v 1.6 2003/04/24 04:10:33 phil Exp $ */
+/* $Id: bal.c,v 1.7 2020-09-27 19:45:56 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -12,13 +12,7 @@
 #include "lib.h"			/* getbal() prototype */
 
 int
-getbal(sp, dp)
-    struct spec *sp;
-    struct descr *dp;
-{
-#if 0
-    UNDF(NORET);
-#else  /* not 0 */
+getbal(struct spec *sp, struct descr *dp) {
     int len;
     char *cp;
     int count, j;
@@ -50,6 +44,5 @@ getbal(sp, dp)
 	return 0;
     S_L(sp) += j;
     return 1;				/* true (success) */
-#endif /* not 0 */
 }
 
