@@ -1,4 +1,4 @@
-/* $Id: dynamic.c,v 1.6 2010/12/04 06:14:10 phil Exp $ */
+/* $Id: dynamic.c,v 1.8 2020-10-04 19:11:58 phil Exp $ */
 
 /* allocate dynamic region on BSD */
 
@@ -8,11 +8,7 @@
 
 #include <sys/vadvise.h>
 
-#ifdef HAVE_STDLIB_H			/* before stdio */
 #include <stdlib.h>			/* for malloc */
-#else  /* HAVE_STDLIB_H not defined */
-extern void *malloc();
-#endif /* HAVE_STDLIB_H not defined */
 
 /* for lib.h: */
 #include <stdio.h>
@@ -23,16 +19,12 @@ extern void *malloc();
 /* on SunOS use valloc(3) + madvise(2)?? */
 
 char *
-dynamic( size )
-    size_t size;
-{
+dynamic(size_t size) {
     return malloc(size);
 }
 
 void
-vm_gc_advise(gc)
-    int gc;
-{
+vm_gc_advise(int gc) {
     if (gc)
 	vadvise(VA_ANOM);		/* warn VM we're random during GC */
     else
