@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.10 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.12 2020-10-13 04:47:53 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -20,11 +20,11 @@
  */
 
 #ifdef GETRUSAGE_BUG
-static real_t last_mstime = 0.0;	/* XXX belongs in vars.h? */
+static VAR real_t last_mstime = 0.0;
 #endif /* GETRUSAGE_BUG defined */
 
 real_t
-mstime() {
+mstime(void) {
     struct rusage ru;
     register real_t x;
 
