@@ -1,4 +1,4 @@
-/* $Id: suspend.c,v 1.5 2003/04/21 23:06:56 phil Exp $ */
+/* $Id: suspend.c,v 1.6 2020-09-27 21:59:59 phil Exp $ */
 
 /*
  * process suspend
@@ -18,8 +18,7 @@
 
 
 void
-proc_suspend()
-{
+proc_suspend(void) {
     /* let default action occur */
     signal(SIGTSTP, SIG_DFL);
 
