@@ -1,4 +1,4 @@
-/* $Id: intspc.c,v 1.4 2003/07/04 20:01:09 phil Exp $ */
+/* $Id: intspc.c,v 1.6 2020-10-13 04:47:53 phil Exp $ */
 
 /*
  * convert from integer to string using sprintf %lld (in ISO C99)
@@ -18,17 +18,10 @@
 
 #include "equ.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#else  /* NO_STATIC_VARS not defined */
-static char strbuf[32];			/* 2^64 is only 21 chars! */
-#endif /* NO_STATIC_VARS not defined */
+static VAR char strbuf[32];		/* 2^64 is only 21 chars! */
 
 void
-intspc(sp, dp)
-    struct spec *sp;
-    struct descr *dp;
-{
+intspc(struct spec *sp, struct descr *dp) {
     sprintf( strbuf, "%lld", D_A(dp) );
     S_A(sp) = (int_t) strbuf;		/* OY! */
     S_F(sp) = 0;
