@@ -1,4 +1,4 @@
-/* $Id: spcint.c,v 1.7 2004/02/03 05:38:08 phil Exp $ */
+/* $Id: spcint.c,v 1.11 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * convert from strings to integer using strtoll (in ISO C99)
@@ -22,17 +22,10 @@
 #include "res.h"
 #include "data.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 int
-spcint(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
+spcint(struct descr *dp, struct spec *sp) {
     char buffer[64];			/* ??? */
-    int_t len;
+    size_t len;
     char *cp;
     int_t temp;
 
@@ -49,7 +42,7 @@ spcint(dp, sp)
 
     if (len > sizeof(buffer)-1)
 	len = sizeof(buffer)-1;
-    bcopy( cp, buffer, (long)len );	/* XXX SIZE_T */
+    memcpy(buffer, cp, (size_t)len);
     buffer[len] = '\0';
 
     errno = 0;
