@@ -1,4 +1,4 @@
-/* $Id: sys.c,v 1.3 2003/04/21 23:18:05 phil Exp $ */
+/* $Id: sys.c,v 1.5 2020-11-13 19:44:40 phil Exp $ */
 
 /* DJGPP/MS-DOS support for HOST() */
 
@@ -8,22 +8,19 @@
 
 #include <dos.h>
 #include <stdio.h>
+#include <string.h>			/* strcpy */
 
 #include "h.h"
 #include "snotypes.h"
 #include "lib.h"
 
 void
-hwname(cp)
-    char *cp;
-{
+hwname(char *cp) {
     strcpy(cp, "x86");
 }
 
 void
-osname(cp)
-    char *cp;
-{
+osname(char *cp) {
     sprintf(cp, "%s %d.%d", _os_flavor, _osmajor, _osminor);
 #ifdef HAVE_DXE2
     strcat(cp, "+DXE2");
