@@ -1,4 +1,4 @@
-/* $Id: tty.c,v 1.7 2003/05/20 17:05:16 phil Exp $ */
+/* $Id: tty.c,v 1.8 2020-09-14 00:53:07 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -16,9 +16,8 @@
  */
 
 int
-fisatty(f, fname)
+fisatty(f)
     FILE *f;
-    char *fname;
 {
     return FALSE;			/* why not? */
 }
