@@ -1,4 +1,4 @@
-/* $Id: execute.c,v 1.7 2012/01/04 00:09:09 phil Exp $ */
+/* $Id: execute.c,v 1.9 2020-09-27 22:28:04 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -9,6 +9,7 @@
 #endif /* HAVE_UNISTD_H defined */
 
 #include <stdio.h>
+
 #include "h.h"
 #include "snotypes.h"
 #include "lib.h"
@@ -22,9 +23,7 @@
 #endif /* SH_PATH2 not defined */
 
 void
-execute(buf)
-    char *buf;
-{
+execute(char *buf) {
     execl(SH_PATH, "sh", "-c", buf, NULL); /* XXX SH_NAME? */
 
     /* must not have found shell; try alternate */
