@@ -1,4 +1,4 @@
-/* $Id: exists.c,v 1.3 2003/04/22 00:54:02 phil Exp $ */
+/* $Id: exists.c,v 1.5 2020-09-27 22:15:22 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -13,10 +13,24 @@
 #include "lib.h"
 
 int
-exists(path)
-    char *path;
-{
+exists(char *path) {
     struct stat st;
 
     return stat(path, &st) >= 0;
 }
+
+int
+isdir(char *path) {
+    struct stat st;
+
+    return stat(path, &st) >= 0 && S_ISDIR(st.st_mode);
+}
+
+int
+abspath(char *path) {
+#ifdef ABSPATH
+    return ABSPATH(path);
+#else
+    return *path == '/';
+#endif
+}
