@@ -1,4 +1,4 @@
-/* $Id: expops.c,v 1.17 2012/01/22 18:51:11 phil Exp $ */
+/* $Id: expops.c,v 1.19 2020-10-13 04:47:53 phil Exp $ */
 
 /*
  * support for exponentiation, using pow() function.
@@ -20,15 +20,8 @@
 # include "macros.h"
 # include "lib.h"			/* own prototypes */
 
-# ifdef NO_STATIC_VARS
-# include "equ.h"
-# include "vars.h"
-# endif /* NO_STATIC_VARS defined */
-
 int
-expint(result,x,y)
-    struct descr *result, *x, *y;
-{
+expint(struct descr *result, struct descr *x, struct descr *y) {
     int_t ix, iy;
     int_t p;
 
@@ -75,9 +68,7 @@ expint(result,x,y)
 }
 
 int
-exreal(result,x,y)
-    struct descr *result, *x, *y;
-{
+exreal(struct descr *result, struct descr *x, struct descr *y) {
     real_t r;
 
     /* XXX use repeated mutiplies? */
