@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.6 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.7 2020-09-27 22:15:22 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -24,7 +24,7 @@
 #endif /* HZ not defined */
 
 real_t
-mstime() {
+mstime(void) {
     struct tms tms;
 
     times(&tms);
