@@ -1,4 +1,4 @@
-/* $Id: spcint.c,v 1.5 2003/04/24 16:17:27 phil Exp $ */
+/* $Id: spcint.c,v 1.9 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * convert from string to integer
@@ -23,20 +23,13 @@
 #include "res.h"
 #include "data.h"			/* for SPITCL */
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 #define TC '|'
 #define EXTRA 2				/* NUL + terminator */
 
 int
-spcint(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
+spcint(struct descr *dp, struct spec *sp) {
     char buffer[64];			/* ??? */
-    int_t len;
+    size_t len;
     char *cp;
     long l;
     char t;
@@ -62,7 +55,7 @@ spcint(dp, sp)
     if (len > sizeof(buffer)-EXTRA)
 	len = sizeof(buffer)-EXTRA;
     
-    bcopy( cp, buffer, len );
+    memcpy(buffer, cp, len);
     
     buffer[len++] = TC;
     buffer[len] = '\0';
