@@ -1,4 +1,4 @@
-/* $Id: spreal.c,v 1.5 2003/04/24 16:17:27 phil Exp $ */
+/* $Id: spreal.c,v 1.8 2020-10-13 04:47:53 phil Exp $ */
 
 /*
  * convert from string to real
@@ -23,20 +23,13 @@
 #include "res.h"
 #include "data.h"			/* for SPITCL */
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 #define TC '|'
 #define EXTRA 2				/* NUL + terminator */
 
 int
-spreal(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
+spreal(struct descr *dp, struct spec *sp) {
     char buffer[64];			/* ??? */
-    int len;
+    size_t len;
     char *cp;
     double d;
     char t;
@@ -62,7 +55,7 @@ spreal(dp, sp)
     if (len > sizeof(buffer)-EXTRA)
 	len = sizeof(buffer)-EXTRA;
 
-    bcopy( cp, buffer, len );
+    memcpy(buffer, cp, len);
     buffer[len++] = TC;
     buffer[len] = '\0';
     if (sscanf(buffer, "%lf%c", &d, &t) != 2 || t != TC)
