@@ -1,4 +1,4 @@
-/* $Id: suspend.c,v 1.4 2003/04/21 23:06:56 phil Exp $ */
+/* $Id: suspend.c,v 1.5 2020-09-27 22:15:22 phil Exp $ */
 
 /*
  * process suspend
@@ -18,7 +18,6 @@
 #include "lib.h"
 
 void
-proc_suspend()
-{
+proc_suspend(void) {
     kill(getpid(), SIGSTOP);		/* use 0 for process group? */
 }
