@@ -1,4 +1,4 @@
-/* $Id: sys.c,v 1.6 2003/06/06 16:11:10 phil Exp $ */
+/* $Id: sys.c,v 1.7 2020-09-27 22:15:22 phil Exp $ */
 
 /* generic support for HOST() on systems with no uname(2) */
 
@@ -14,15 +14,11 @@
 #include "str.h"
 
 void
-hwname(cp)
-    char *cp;
-{
+hwname(char *cp) {
     strcpy(cp, HWNAME);
 }
 
 void
-osname(cp)
-    char *cp;
-{
+osname(char *cp) {
     strcpy(cp, OSNAME);
 }
