@@ -1,87 +1,91 @@
-/* $Id: init.c,v 1.80 2012/01/05 02:56:00 phil Exp $ */
+/* $Id: init.c,v 1.138 2022-02-17 01:44:12 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
-#ifdef HAVE_STDLIB_H			/* before stdio */
 #include <stdlib.h>			/* for malloc */
-#else  /* HAVE_STDLIB_H not defined */
-extern void *malloc();
-#endif /* HAVE_STDLIB_H not defined */
-
 #include <stdio.h>
 #include <signal.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>			/* xxx_FILENO */
+#endif /* HAVE_UNISTD_H defined */
+
+#ifdef HAVE_IO_H
+#include <io.h>				/* _dup */
+#endif /* HAVE_IO_H */
+
 #include "h.h"
 #include "snotypes.h"
 #include "macros.h"
-#include "lib.h"			/* io_init(), io_input() protos */
+#include "lib.h"			/* io_input() protos */
 #include "str.h"			/* strlen() */
 #include "units.h"			/* UNIT[IOPT] */
 
-#include "equ.h"			/* SIL equ's */
-#include "res.h"			/* for data.h */
-#include "data.h"			/* SIL data */
+#include "equ.h"			/* {PS,IS,ST}SIZE NODESZ SPDLSZ */
+#include "res.h"			/* UC SIL var names */
+#include "data.h"			/* res */
 #include "proc.h"			/* for SYSCUT() */
+#include "load.h"			/* io_fname  */
+#include "snobol4.h"	      /* INIT_OK, io_input_file, io_mkfile(_noclose) */
+#include "globals.h"
+
+#include "version.h"
 
 /* return type of signal handler functions */
 #ifndef SIGFUNC_T
 #define SIGFUNC_T void
 #endif /* SIGFUNC_T not defined */
 
+#ifndef SIGFUNC_ARG
+#define SIGFUNC_ARG int sig
+#endif /* SIGFUNC_ARG not defined */
+
+#ifndef DISCARD_SIGFUNC_ARG
+#define DISCARD_SIGFUNC_ARG (void)sig
+#endif /* SIGFUNC_ARG not defined */
+
 #ifndef NDYNAMIC
-#define NDYNAMIC (64*1024)		/* default dynamic region size */
+#define NDYNAMIC (512*1024)		/* default dynamic region size */
 #endif /* NDYNAMIC not defined */
 
 #ifndef PSSIZE
-#define PSSIZE (SPDLDR/DESCR)		/* default pattern stack size */
+#define PSSIZE SPDLSZ			/* default pattern stack size */
 #endif /* PSSIZE not defined */
 
 #ifndef ISSIZE
 #define ISSIZE STSIZE
 #endif /* ISSIZE not defined */
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#else  /* NO_STATIC_VARS not defined */
-
 #ifdef HAVE_BUILD_VARS
 extern const char build_date[];		/* from build.c */
 #endif /* HAVE_BUILD_VARS defined */
 
-/* global for access by io.c; */
-int rflag;
-int lflag;
-
-/* global for access by host.c; */
-size_t ndynamic;
-size_t pmstack;
-size_t istack;
-char *params;
-char **argv;
-int firstarg;
-int argc;
-int nfiles;
-#endif /* NO_STATIC_VARS not defined */
+#ifndef STDOUT_FILENO
+#define STDOUT_FILENO 1
+#endif /* STDOUT_FILENO not defined */
 
+#ifdef NEED_GETOPT_EXTERNS
+/* needed w/ own getopt & on SunOS4?! */
 extern int optind;
 extern char *optarg;
-extern int getopt();
+#endif
+
+static VAR int xflag;
+static VAR void *ppmstack;
+static VAR FILE *termin;
+
+static void init_signals(void);
 
 static void
-p( flag, str )
-    char flag;
-    char *str;
-{
+p(int flag, const char *str) {
     fprintf(stderr, "-%c\t%s\n", flag, str);
 }
 
 static char *
-showk( n )
-    int n;
-{
-    static char buf[32];
+showk(int n) {
+    static VAR char buf[32];		/* XXX VAR shouldn't matter? */
     int k, m;
 
     k = n / 1024;
@@ -97,23 +101,20 @@ showk( n )
     return buf;
 }
 
-static void
-usage( jname, justversion )
-    char *jname;
-    int justversion;
-{
+static int
+usage(char *jname, int justversion) {
     extern const char snoname[], vers[], vdate[];
     fprintf( stderr, "%s version %s (%s)\n", snoname, vers, vdate );
 #ifdef HAVE_BUILD_VARS
     fprintf( stderr, "built %s\n", build_date);
 #endif /* HAVE_BUILD_VARS defined */
     if (justversion)
-	exit(1);
+	return 0;
 
     fprintf( stderr,
 	    "Usage: %s [options...] [files...] [parameters...]\n", jname );
 /* XXX stuff about parameters */
-    p('b',"toggle display of startup banner");
+    p('b',"disable display of startup banner");
     fprintf(stderr,
 	    "-d DESCRS[km]\n\tsize of dynamic region in descriptors (default: %s)\n", showk(NDYNAMIC));
     p('f',"toggle folding of identifiers to upper case (-CASE)");
@@ -128,26 +129,30 @@ usage( jname, justversion )
     p('s',"toggle display of statistics");
     fprintf(stderr, "-u PARMS\n\tparameter data available via HOST(0)\n");
     p('v',"display version and exit");
-#ifdef PRELOAD
-    p('L',"toggle pre-loading");
-#endif /* PRELOAD defined */
+    p('x',"force display of startup banner");
+    p('z',"show directory search path in use");
+
+#ifdef BLOCKS
+    p('B',"toggle SNOBOL4B operators (-[NO]BLOCKS)");
+#endif
+    fprintf(stderr, "-I DIR\tadd directory to search path\n");
+    fprintf(stderr, "-L SOURCE\n");
+    fprintf(stderr, "\tload source file before user program\n");
     p('M',"process multiple files for program code");
+    p('N',"clear search path");
     fprintf(stderr, "-P DESCRS[km]\n");
     fprintf(stderr, "\tsize of pattern match stack in descriptors (default: %s)\n", showk(PSSIZE));
     fprintf(stderr, "-S DESCRS[km]\n");
     fprintf(stderr, "\tsize of interpreter stack in descriptors (default: %s)\n", showk(ISSIZE));
-
+    fprintf(stderr, "-U\tmake all stdio I/O unbuffered\n");
     fprintf(stderr, "\n");
     fprintf(stderr, "For memory region sizes a suffix of 'k' (1024) and 'm' (1024*1024)\n");
     fprintf(stderr, "can be used. A descriptor takes up %d bytes.\n", (int)DESCR );
-    exit(1);
+    return 1;
 }
 
 static int
-getk( str, out )
-    char *str;
-    size_t *out;
-{
+getk(char *str, size_t *out) {
     char suff;
     unsigned long val;
     switch (sscanf(str, "%lu%c", &val, &suff)) {
@@ -174,10 +179,8 @@ getk( str, out )
  */
 
 static char *
-getargs(start, sp)
-    int start;				/* which argument to start on */
-    struct spec *sp;			/* dest spec, or NULL */
-{
+getargs(int start,			/* which argument to start on */
+	struct spec *sp) {		/* dest spec, or NULL */
     int i;
     char *parms;
     register char *pp;
@@ -215,38 +218,28 @@ getargs(start, sp)
     return parms;
 }
 
-void
-io_init()				/* here from INIT */
-{
-    FILE *termin;
-
+/* return zero on failure */
+static int
+io_init(int interactive) {		/* here from init_args() */
     io_initvars();
 
+    if (!interactive)
+	return 1;
+
+    init_signals();
+
     if (nfiles == 0) {			/* no input file(s)? */
-#ifdef MEM_IO_TEST
-	char *str = "\tOUTPUT = 'Hello World'\n\tOUTPUT = INPUT\nEND\nFOO\n";
-	io_input_string( "input", str );
-#else  /* MEM_IO_TEST not defined */
-	/* read code from stdin.... Macro SPITBOL requires '-' for this */
-#ifdef PRELOAD
+	/* note: io_mkfile blows away preload list */
 	io_input_file("-");		/* implicit "-"! */
-#else  /* PRELOAD not defined */
-	/* blows away preload list */
-	if (!io_mkfile_noclose(UNITI, stdin, STDIN_NAME)) {
-	    perror("could not attach stdin to INPUT");
-	    exit(1);
-	}
-#endif /* PRELOAD not defined */
-#endif /* MEM_IO_TEST not defined */
     }
     else {
 	if (!io_skip(UNITI)) {		/* force file open */
-	    char *fname;
+	    const char *fname;
 	    fname = io_fname(UNITI);
 	    if (!fname)
 		fname = "unknown input file";
 	    perror(fname);
-	    exit(1);
+	    return 0;
 	}
     }
 
@@ -254,71 +247,86 @@ io_init()				/* here from INIT */
 
     if (!D_A(LISTCL) && !io_mkfile_noclose(UNITO, stdout, STDOUT_NAME)) {
 	perror("could not attach stdout to OUTPUT");
-	exit(1);
+	return 0;
     }
 
     if (!io_mkfile_noclose(UNITP, stderr, STDERR_NAME)) {
 	perror("could not attach stderr to TERMINAL");
-	exit(1);
+	return 0;
     }
 
     termin = term_input();		/* call system dependant function */
     if (termin && !io_mkfile_noclose(UNITT, termin, TERMIN_NAME)) {
 	perror("could not open TERMINAL for input");
-	exit(1);
+	return 0;
     }
+    return 1;
 } /* io_init */
 
-#ifdef PRELOAD
-static int
-trypreload( var, defdir, file )
-    char *var, *defdir, *file;
-{
-    char *path;
+/* called after -I paths have already been added, before preload, sources */
+static void
+pathinit(char *av0, int std_includes) {
+    char *env;
 
-    if (var || defdir) {
-	char *dir = NULL;
-	int ret = 0;
+    /* XXX SHARED FIX: some of this only needs to be done once */
 
-	if (var)
-	    dir = getenv(var);
+    /* generate directory names for HOST() even if not in search path */
 
-	if (!dir)
-	    dir = defdir;
+    /* /usr/local/lib/snobol4 or C:\Program Files\SNOBOL4 */
+    snolib_base = getenv("SNOLIB");	/* old variable */
+    if (!snolib_base)
+	snolib_base = SNOLIB_BASE;
 
-	path = malloc(strlen(dir) + 1 + strlen(file) + 1);
-	if (!path)
-	    return 0;
-	sprintf(path, "%s%s%s", dir, DIR_SEP, file);
-	if (exists(path)) {
-	    io_input_file(path);
-	    ret = 1;
-	}
-	free(path);
-	return ret;
+    /* versioned directory */
+    /* /usr/local/lib/snobol4/x.y or C:\Program Files\SNOBOL4\x.y */
+    snolib_vers = strjoin(snolib_base, DIR_SEP, VERSION, NULL);
+
+    /* distribution files (version-specific) */
+    snolib_vlib = strjoin(snolib_vers, DIR_SEP, "lib", NULL);
+
+#ifdef HAVE_FIND_SNOLIB_DIRECTORY
+    /* see if directories exist, if not, find via argv[0] */
+    find_snolib_directory(av0, &snolib_vers, &snolib_vlib);
+#else
+    (void) av0;
+#endif
+
+    /* local, version-specific */
+    snolib_vlocal = strjoin(snolib_vers, DIR_SEP, "local", NULL);
+
+    /* local -- all versions */
+    snolib_local = strjoin(snolib_base, DIR_SEP, "local", NULL);
+
+    /* add to search path (after . & -I options) */
+    env = getenv("SNOPATH");
+    if (env) {
+	io_add_lib_path(env);
     }
-    else if (exists(file)) {
-	io_input_file(file);
-	return 1;
+    else if (std_includes) {
+	io_add_lib_dir(snolib_vlib);	/* dist, (version-specific) */
+	io_add_lib_dir(snolib_vlocal);	/* local, version-specific */
+	io_add_lib_dir(snolib_local);	/* local -- all versions */
+	io_add_lib_dir(snolib_base);	/* old directory */
     }
-    return 0;
-} /* trypreload */
-#endif /* PRELOAD defined */
+#ifdef EXTRA_SNOPATH
+    if (std_includes)
+	io_add_lib_path(EXTRA_SNOPATH);
+#endif
+}
 
 /* called from main.c after init_data, before xfer to SIL BEGIN label */
-void
-init_args( ac, av )
-    int ac;
-    char *av[];
-{
+/* returns exit status, or INIT_OK on success */
+int
+init_args(int ac, char *av[], int interactive) {
     int errs;
     int c;
     int multifile;
     int justversion;
-#ifdef PRELOAD
-    int preload = 0;			/* default to OFF! */
-#endif /* PRELOAD defined */
+    int showpaths = 0;
+    int std_includes = 1;
 
+    /* in globals.h */
+    rflag = lflag = unbuffer_all = nfiles = firstarg = 0;
     ndynamic = NDYNAMIC;
     pmstack = PSSIZE;
     istack = ISSIZE;
@@ -326,6 +334,7 @@ init_args( ac, av )
     /* save in globals for HOST(), getparm(), init() */
     argc = ac;
     argv = av;
+    /* end in globals.h */
 
 #ifdef vms
     argc = getredirection(argc, argv);
@@ -334,6 +343,7 @@ init_args( ac, av )
     errs = 0;
     multifile = 0;			/* SITBOL behavior */
     justversion = 0;
+    io_add_lib_dir(".");		/* XXX but not if set-uid??? */
 
     /*
      * ***** NOTE ******
@@ -350,10 +360,11 @@ init_args( ac, av )
      *		added, but it better not want an argument!)
      */
 
-    while ((c = getopt(argc, argv, "+bd:fghkl:nprsu:vLMP:S:")) != -1) {
+    /* getopt not thread safe!!! use private vers that takes optind/optarg? */
+    while ((c = getopt(argc, argv, "+bd:fghkl:nprsu:vxzBI:L:MNP:S:U")) != -1) {
 	switch (c) {
 	case 'b':
-	    D_A(BANRCL) = !D_A(BANRCL);	/* toggle banner output */
+	    D_A(BANRCL) = 0;		/* disable banner output */
 	    break;
 
 	case 'd':			/* number of dynamic descrs */
@@ -370,11 +381,6 @@ init_args( ac, av )
 	    D_A(GCTRCL) = -1;		/* enable &GCTRACE */
 	    break;
 
-	case 'v':			/* version */
-	    justversion = 1;
-	    errs++;
-	    break;
-
 	case 'h':			/* help */
 	    justversion = 0;
 	    errs++;
@@ -388,11 +394,15 @@ init_args( ac, av )
 	case 'l':			/* -LIST */
 	    {
 		/* now takes an argument!!! */
-		FILE *listfile = fopen(optarg, "w");
+		FILE *listfile;
+		if (strcmp(optarg, "-") == 0)
+		    listfile = fdopen(dup(STDOUT_FILENO), "w");
+		else
+		    listfile = fopen(optarg, "w");
 		D_A(LISTCL) = lflag = 1;
 		if (!listfile || !io_mkfile(UNITO, listfile, optarg)) {
 		    perror(optarg);
-		    exit(1);
+		    return 1;
 		}
 	    }
 	    break;
@@ -414,19 +424,56 @@ init_args( ac, av )
 	    break;
 
 	case 'u':			/* parameter data */
-	    params = optarg;
+	    params = strdup(optarg);
 	    break;
 
-#ifdef PRELOAD
+	case 'v':			/* version */
+	    justversion = 1;
+	    errs++;
+	    break;
+
+	case 'x':
+	    xflag = D_A(BANRCL) = 1;	/* force banner output */
+	    break;
+
+	case 'z':
+	    showpaths = 1;
+	    break;
+
+#ifdef BLOCKS
+	case 'B':			/* toggle BLOCKS */
+	    D_A(BLOKCL) = !D_A(BLOKCL);
+	    break;
+#endif
+
+	case 'I':			/* include path dir */
+	    io_add_lib_dir(optarg);
+	    break;
+
 	case 'L':			/* pre-load files */
-	    preload = !preload;
+	    if (exists(optarg)) 
+		io_input_file(optarg);
+	    else {
+		/* look for file on SNOPATH (BUG: not yet populated?) */
+		/* XXX check for no DIR_SEP? */
+		char *path = io_lib_find(NULL, optarg, ".inc");
+		if (path)
+		    io_input_file(path);
+		else {
+		    fprintf(stderr, "%s: file not found\n", optarg);
+		    return 1;
+		}
+	    }
 	    break;
-#endif /* PRELOAD defined */
 
 	case 'M':			/* multi-file input */
 	    multifile = !multifile;
 	    break;
 
+	case 'N':			/* no standard includes */
+	    std_includes = 0;
+	    break;
+
 	case 'P':			/* pattern match stack size */
 	    if (!getk(optarg, &pmstack))
 		errs++;
@@ -437,52 +484,38 @@ init_args( ac, av )
 		errs++;
 	    break;
 
+	case 'U':			/* make all stdio I/O unbuffered */
+	    unbuffer_all = 1;
+	    break;
+
 	default:
 	    errs++;
 	}
+    } /* while getopt */
+
+    pathinit(av[0], std_includes);
+
+    /* XXX option to disable? */
+    io_preload();
+
+    if (!unbuffer_all) {
+	char *u = getenv("SNOBOL4UNBUFFERED"); /* like PYTHONUNBUFFERED */
+	if (u && *u)
+	    unbuffer_all = 1;
     }
 
-#ifdef PRELOAD
-    /*
-     * NOTE! THIS FEATURE IS DISABLED, UNDOCUMENTED and UNSUPPORTED.
-     * IT MAY DISAPPEAR ALTOGETHER!
-     * Or, It may appear in a future release, but not in this exact form!
-     *
-     * Use at your own risk!  It may make your code less portable
-     * than if you had used -INCLUDE "/path/file.sno"!!!!
-     */
-
-    if (preload) {
-	/* XXX unsafe!! defend against world write dirs? suid?? */
-
-	/* try version based filename(s) as well as unversioned? */
-	/* XXX defend against including same file twice?! use io_include()? */
-
-	/*
-	 * modification of this file reserved to CSNOBOL4 distribution
-	 * creator!! Do not edit locally, it may be crushed by the
-	 * install process.  YOU HAVE BEEN WARNED!!!
-	 */
-	trypreload("SNODIR", SNOLIB_DIR, "dist-preload.sno");
-
-	/* all of the following files may be created/modified by local users */
-	trypreload("SNODIR", SNOLIB_DIR, "preload.sno");
-	trypreload("HOME",   NULL,	 "preload.sno");
-	trypreload(NULL,     NULL,	 "preload.sno");
-    }
-#endif /* PRELOAD defined */
-
     /*
      * append first file (or all additional args until "--" seen
      * in "multi-file" mode) to INPUT stream
      */
-
     while (optind < argc) {
 	if (strcmp(argv[optind], "--") == 0) { /* terminator? */
 	    optind++;			/* skip it */
 	    break;			/* leave loop */
 	}
 	io_input_file( argv[optind] );
+	if (!xflag)
+	    D_A(BANRCL) = 0;		/* disable banner output */
 	optind++;
 	nfiles++;
 	if (!multifile)			/* not in multi-file mode? */
@@ -496,50 +529,67 @@ init_args( ac, av )
 
     firstarg = optind;			/* save for HOST(3) */
 
-    if (errs) {
-	usage(argv[0], justversion);
+    if (errs)
+	return usage(argv[0], justversion);
+
+    if (!io_init(interactive))		/* AFTER io_input calls! */
+	return 1;
+
+    if (showpaths) {			/* after io_init() */
+	io_show_paths();
+	return 0;
     }
 
-    io_init();				/* AFTER io_input calls! */
 #ifdef HAVE_OS_INIT
     os_init();
 #endif /* HAVE_OS_INIT defined */
+
+    return INIT_OK;
 }
 
-#ifndef NO_STATIC_VARS
-volatile int math_error;		/* see macros.h */
-#endif /* NO_STATIC_VARS not defined */
+volatile VAR int math_error;		/* see macros.h */
 
 static SIGFUNC_T
-math_catch(sig)
-    int sig;
-{
+math_catch(SIGFUNC_ARG) {
 #ifdef SIGFPE
     signal(SIGFPE, math_catch);
 #endif /* SIGFPE defined */
 #ifdef SIGOVER
     signal(SIGOVER, math_catch);
 #endif /* SIGOVER defined */
+    DISCARD_SIGFUNC_ARG;
 
     math_error = TRUE;
     /* XXX need to longjump out on some systems to avoid restarting insn? */
 }
 
+/* handle fatal errors */
 static SIGFUNC_T
-err_catch(sig)
-    int sig;
-{
+err_catch(SIGFUNC_ARG) {
     D_A(SIGNCL) = sig;			/* save signal number for output */
-    // only for fatal errors? 
-    // else check SIGNCL in interpreter loop and go to FTLTST (for SETEXIT handling)
     SYSCUT(NORET);
 }
 
+/* handle ^C (SIGINT) here */
+static SIGFUNC_T
+sig_catch(SIGFUNC_ARG) {
+    if (D_A(COMPCL) || D_A(ERRLCL) == 0) /* in compiler or &ERRLIMIT == 0*/
+	err_catch(sig);			/* treat as before */
+
+    /*
+     * top of INIT checks UINTCL and causes "User Interrupt" error
+     * which can be caught with SETEXIT() and continued with :(SCONTINUE)
+     * Keep count, so windoze code in io.c can detect ^C vs EOF
+     */
+    D_A(UINTCL)++;
+    signal( SIGINT, sig_catch );	/* re-arm for Win32/VC10 */
+}
+
 #ifdef SIGTSTP
 static SIGFUNC_T
-suspend(sig)
-    int sig;
-{
+suspend(SIGFUNC_ARG) {
+    DISCARD_SIGFUNC_ARG;
+
     tty_suspend();			/* restore tty mode(s) */
 
     /* reestablish handler (does any system with job control,
@@ -553,8 +603,7 @@ suspend(sig)
 
 /* called by SIL INIT macro (first SIL op executed) */
 void
-init()
-{
+init(void) {
     char *ptr;
 
     /****************
@@ -585,7 +634,7 @@ init()
 
     pmstack *= DESCR;			/* get bytes */
 
-    ptr = malloc(pmstack);		/* NOTE: malloc(), not dynamic() */
+    ptr = ppmstack = malloc(pmstack);	/* NOTE: malloc(), not dynamic() */
     if (ptr == NULL) {
 	fprintf(stderr, "%s: could not allocate pattern stack of %lu bytes\n",
 		argv[0], (unsigned long)pmstack);
@@ -626,12 +675,14 @@ init()
 
     /* pointer to end of stack, for overflow checks */
     D_A(STKEND) = (int_t) ptr + istack;
+}
 
-    /****************
+static void
+init_signals(void) {
+    /*
      * setup signal handlers
      */
-
-    signal( SIGINT, err_catch );
+    signal( SIGINT, sig_catch );
 
     /* catch bad memory references */
     signal( SIGSEGV, err_catch );
@@ -664,12 +715,71 @@ init()
 #ifdef SIGTSTP
     signal(SIGTSTP, suspend);
 #endif /* SIGTSTP defined */
-}
+} /* init_signals */
 
 /* 9/21/96 - set specifier to point to entire command line for &PARM */
 int
-getparm( sp )
-    struct spec *sp;
-{
+getparm(struct spec *sp) {
     return getargs(0, sp) != NULL;
 }
+
+/* 10/14/2020! -- free memory allocated in getparm */
+int
+freeparm(struct spec *sp) {
+    if (S_A(sp))
+	free((void *)S_A(sp));
+    return 0;
+}
+
+#ifdef SHARED
+struct cleanup {
+    struct cleanup *next;
+    void (*func)(void);
+};
+
+static TLS struct cleanup *cleanups;
+#endif
+
+/* void function taking pointer to void function with no args */
+void
+reg_cleanup(void (*func)(void)) {
+#ifdef SHARED
+    struct cleanup *cp = malloc(sizeof(struct cleanup));
+    cp->next = cleanups;
+    cp->func = func;
+    cleanups = cp;
+#else
+    (void) func;
+#endif
+}
+
+#ifdef SHARED
+/* cleanup for shared library */
+void
+cleanup(void) {
+    struct cleanup *cp, *next;
+
+    if (params)
+	free(params);
+
+    for (cp = cleanups; cp; cp = next) {
+	next = cp->next;
+	if (cp->func)
+	    (cp->func)();
+	free(cp);
+    }
+    cleanups = NULL;
+
+    free((void *)D_A(HDSGPT));		/* free dynamic region */
+    free((void *)D_A(STKHED));		/* stack */
+    free(ppmstack);			/* pattern match stack */
+
+    free(snolib_local);
+    free(snolib_vers);
+    free(snolib_vlib);
+    free(snolib_vlocal);
+
+    if (termin)
+	fclose(termin);			/* last, in case. should be a dup */
+}
+#endif
