@@ -1,4 +1,4 @@
-/* $Id: lexcmp.c,v 1.7 2003/04/21 23:20:08 phil Exp $ */
+/* $Id: lexcmp.c,v 1.8 2020-09-27 19:45:56 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -12,9 +12,7 @@
 #include "lib.h"
 
 int
-lexcmp(a,b)
-    struct spec *a, *b;
-{
+lexcmp(struct spec *a, struct spec *b) {
     char *x, *y;
     int i, j;
 
