@@ -1,4 +1,4 @@
-/* $Id: intspc.c,v 1.3 2003/07/04 20:01:09 phil Exp $ */
+/* $Id: intspc.c,v 1.5 2020-10-13 04:47:53 phil Exp $ */
 
 /*
  * long long to string (systems without long long library support)
@@ -18,17 +18,10 @@
 
 #include "equ.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#else  /* NO_STATIC_VARS not defined */
-static char strbuf[32];			/* 2^64 is only 21 chars! */
-#endif /* NO_STATIC_VARS not defined */
+static VAR char strbuf[32];	      /* 2^64 is only 21 chars! */
 
 void
-intspc(sp, dp)
-    struct spec *sp;
-    struct descr *dp;
-{
+intspc(struct spec *sp, struct descr *dp) {
     char *bp;
     int_t x;
     unsigned INT_T u;
