@@ -1,4 +1,4 @@
-/* $Id: spcint.c,v 1.5 2003/04/24 16:17:27 phil Exp $ */
+/* $Id: spcint.c,v 1.8 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * convert from strings to long long using ad hoc code
@@ -23,16 +23,9 @@
 #include "res.h"
 #include "data.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 int
-spcint(dp, sp)
-    struct descr *dp;
-    struct spec *sp;
-{
-    int_t len;
+spcint(struct descr *dp, struct spec *sp) {
+    size_t len;
     char *cp;
     int_t temp;
     int signum;
