@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.5 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.8 2020-10-13 18:40:46 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -11,25 +11,27 @@
 #include "snotypes.h"
 #include "lib.h"
 
-static int first_time = -1;
-static long start_time;
+static VAR long start_time;
 
 /*
- * sigh; use ansi-ish clock() -- returns Time Of Day!
+ * sigh; use ansi-ish clock() defined as user + system,
+ *	but wall clock on on MS-DOS?
  */
 
 real_t
-mstime() {
+mstime(void) {
     clock_t t;
 
-    if (first_time == -1) {
-	start_time = (clock_t) clock();
-	first_time = -first_time;
+    if (start_time == 0) {
+	start_time = clock();
+	if (start_time == 0)
+	    start_time = 1;		/* must be non-zero */
 	return 0.0;
     }
 
-    t = (clock_t) clock();
-
+    t = clock();
+    if (t == 0 && start_time == 1)
+	t = 1;
     if (t < start_time)
 	t += 86400L * CLOCKS_PER_SEC;	/* sec/day * clocks/sec */
 
