@@ -1,4 +1,4 @@
-/* $Id: tty.c,v 1.4 2003/04/24 16:29:35 phil Exp $ */
+/* $Id: tty.c,v 1.7 2020-10-18 01:18:05 phil Exp $ */
 
 /*
  * tty mode, echo
@@ -17,10 +17,7 @@
 #include "lib.h"
 
 int
-fisatty(f, fname)
-    FILE *f;
-    char *fname;
-{
+fisatty(FILE *f) {
     /*
      * XXX we can only do tty_read() on keyboard so this better not
      * return true for opens on COM: devices. If so replace "isatty"
@@ -30,41 +27,27 @@ fisatty(f, fname)
 }
 
 void
-tty_save()
-{
+tty_save(void) {
 }
 
 void
-tty_restore()
-{
+tty_restore(void) {
 }
 
 void
-tty_mode( fp, cbreak, noecho, recl )
-    FILE *fp;
-    int cbreak, noecho, recl;
-{
+tty_mode(FILE *fp, int cbreak, int noecho, int recl) {
 }
 
 /* advisory notice */
 void
-tty_close(f)
-    FILE *f;
-{
+tty_close(FILE *f) {
     /* should not be called (fisatty returns FALSE) */
 }
 
 /* called for raw tty reads if TTY_READ_RAW defined */
 int
-tty_read(f, buf, len, raw, noecho, keepeol, fname)
-    FILE *f;
-    char *buf;
-    int len;
-    int raw;
-    int noecho;
-    int keepeol;
-    char *fname;
-{
+tty_read(FILE *f, char *buf, int len,
+	 int raw, int noecho, int keepeol, const char *fname) {
     int cc;
 
     if (!raw)				/* paranoia */
