@@ -1,4 +1,4 @@
-/* $Id: pair.c,v 1.9 2003/05/30 02:34:30 phil Exp $ */
+/* $Id: pair.c,v 1.11 2020-09-27 19:45:56 phil Exp $ */
 
 /*
  * pair.c - attribute pair searches
@@ -16,6 +16,7 @@
 #include "snotypes.h"
 #include "macros.h"
 #include "lib.h"
+#include "equ.h"			/* R & I for DCMP */
 
 #define STATIC_PAIR
 #endif /* STATIC_PAIR not defined */
@@ -27,9 +28,7 @@
 
 /* locate attribute pair by type */
 STATIC_PAIR int
-locapt( d1, d2, d3 )
-    struct descr *d1, *d2, *d3;
-{
+locapt(struct descr *d1, struct descr *d2, struct descr *d3) {
     register int_t a;
     int_t end;
 
@@ -49,9 +48,7 @@ locapt( d1, d2, d3 )
 }
 
 STATIC_PAIR int
-locapv( d1, d2, d3 )
-    struct descr *d1, *d2, *d3;
-{
+locapv(struct descr *d1, struct descr *d2, struct descr *d3) {
     register int_t a;
     int_t end;
 
