@@ -1,4 +1,4 @@
-/* $Id: dynamic.c,v 1.6 2010/12/04 06:14:10 phil Exp $ */
+/* $Id: dynamic.c,v 1.8 2020-10-18 15:35:48 phil Exp $ */
 
 /* allocate dynamic region for POSIX 1003.1b-1993 systems */
 
@@ -9,11 +9,7 @@
 #include <sys/types.h>
 #include <sys/mman.h>
 
-#ifdef HAVE_STDLIB_H                    /* before stdio */
 #include <stdlib.h>                     /* for malloc */
-#else  /* HAVE_STDLIB_H not defined */
-extern void *malloc();
-#endif /* HAVE_STDLIB_H not defined */
 
 /* prefer standard POSIX interface; fall back to BSD */
 #if !defined(POSIX_MADV_RANDOM) && defined(MADV_RANDOM)
@@ -28,22 +24,18 @@ extern void *malloc();
 #include "snotypes.h"
 #include "lib.h"			/* own prototypes */
 
-static char *dbase;
-static size_t dsize;
+static VAR char *dbase;
+static VAR size_t dsize;
 
 char *
-dynamic( size )
-    size_t size;
-{
+dynamic(size_t size) {
     dsize = size;
     dbase = malloc(size);
     return dbase;
 }
 
 void
-vm_gc_advise(gc)
-    int gc;
-{
+vm_gc_advise(int gc) {
     if (gc)
 	posix_madvise(dbase, dsize,  POSIX_MADV_RANDOM); /* random during GC */
     else
