@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.5 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.6 2020-09-27 22:08:32 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -19,7 +19,7 @@
  */
 
 real_t
-mstime() {
+mstime(void) {
     struct tms tms;
     int hz;
 
