@@ -1,4 +1,4 @@
-/* $Id: suspend.c,v 1.3 2003/04/21 23:06:56 phil Exp $ */
+/* $Id: suspend.c,v 1.4 2020-09-27 22:08:32 phil Exp $ */
 
 /*
  * process suspend
@@ -18,7 +18,7 @@
 #include "lib.h"
 
 void
-proc_suspend()
+proc_suspend(void)
 {
     sigset_t set;
     
