@@ -1,4 +1,4 @@
-/* $Id: sys.c,v 1.5 2003/07/04 20:01:09 phil Exp $ */
+/* $Id: sys.c,v 1.6 2020-09-27 22:08:32 phil Exp $ */
 
 /* support for HOST() on systems with POSIX.1 uname(2) */
 
@@ -15,9 +15,7 @@
 #include "str.h"
 
 void
-hwname(cp)
-    char *cp;
-{
+hwname(char *cp) {
 #ifdef HWNAME
     strcpy(cp, HWNAME);
 #else  /* HWNAME not defined */
@@ -31,9 +29,7 @@ hwname(cp)
 }
 
 void
-osname(cp)
-    char *cp;
-{
+osname(char *cp) {
 #ifdef OSNAME
     strcpy(cp, OSNAME);
 #else  /* OSNAME not defined */
