@@ -1,10 +1,11 @@
-/* $Id: term.c,v 1.4 2003/04/21 23:52:43 phil Exp $ */
+/* $Id: term.c,v 1.6 2020-10-16 20:56:21 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
 #include <stdio.h>
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #else  /* HAVE_UNISTD_H not defined */
@@ -21,6 +22,6 @@
  */
 
 FILE *
-term_input() {
-    return fdopen(STDERR_FILENO, "r");
+term_input(void) {
+    return fdopen(dup(STDERR_FILENO), "r");
 }
