@@ -1,4 +1,4 @@
-/* $Id: realst.c,v 1.14 2003/04/22 04:17:24 phil Exp $ */
+/* $Id: realst.c,v 1.18 2020-10-13 04:47:53 phil Exp $ */
 
 /*
  * convert from real to string
@@ -20,26 +20,26 @@
 
 #include "equ.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#else  /* NO_STATIC_VARS not defined */
-static char strbuf[64];
-#endif /* NO_STATIC_VARS not defined */
+static VAR char strbuf[64];
+
+#ifndef REALST_FORMAT
+/* "l" is always redundant? */
+#define REALST_FORMAT "%lg"
+#endif
 
 void
-realst(sp, dp)
-    struct spec *sp;
-    struct descr *dp;
-{
+realst(struct spec *sp, struct descr *dp) {
     char *bp;
 
-    sprintf( strbuf, "%lg", D_RV(dp) );
+    sprintf( strbuf, REALST_FORMAT, D_RV(dp) );
     /*
      * "g" format can print an integer for exact values.
      * make sure we have an exponent or a dot.
+     *
+     * %#g may add dot, but also trailing zeroes!
      */
     bp = strbuf;
-    while (*bp && isdigit(*bp))
+    while (*bp && isdigit((unsigned char)*bp))
 	bp++;
 
     if (*bp == '\0') {
