@@ -1,4 +1,4 @@
-/* $Id: replace.c,v 1.6 2003/04/21 23:49:32 phil Exp $ */
+/* $Id: replace.c,v 1.7 2020-09-27 19:45:56 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -20,12 +20,7 @@
 #endif /* ALPHSZ & MASK */
 
 void
-rplace(sp1, sp2, sp3)
-    struct spec *sp1, *sp2, *sp3;
-{
-#if 0
-    INTR10();
-#else  /* not 0 */
+rplace(struct spec *sp1, struct spec *sp2, struct spec *sp3) {
     int l1, l2, l3;
     char *cp1, *cp2, *cp3;
     char table[ALPHSZ];
@@ -54,5 +49,4 @@ rplace(sp1, sp2, sp3)
 	*cp1 = table[ *cp1 & MASK ];
 	cp1++;
     }	
-#endif /* not 0 */
 }
