@@ -1,4 +1,4 @@
-/* $Id: atan.c,v 1.1 2011/01/24 04:36:25 phil Exp $ */
+/* $Id: atan.c,v 1.5 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -18,11 +18,11 @@
 #include "load.h"
 #include "equ.h"
 
-int
-ATAN( LA_ALIST ) LA_DCL
-{
+pmlret_t
+ATAN( LA_ALIST ) {
     real_t ret = atan(LA_REAL(0));
-    if (!finite(ret))
+    (void) nargs;
+    if (!REAL_ISFINITE(ret))
 	RETFAIL;
     RETREAL(ret);
 }
