@@ -1,4 +1,4 @@
-/* $Id: chop.c,v 1.5 2003/04/21 18:04:19 phil Exp $ */
+/* $Id: chop.c,v 1.8 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SNOBOL4+ compatibility;
@@ -25,10 +25,10 @@
  *	(and were in v7 and BSD4.2)
  */
 
-int
-CHOP( LA_ALIST ) LA_DCL
-{
+pmlret_t
+CHOP( LA_ALIST ) {
     double x;
+    (void) nargs;
     x = LA_REAL(0);
     if (x >= 0) {
 	RETREAL( floor(x) );
