@@ -1,4 +1,4 @@
-/* $Id: cos.c,v 1.8 2005/12/11 16:55:54 phil Exp $ */
+/* $Id: cos.c,v 1.11 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -18,8 +18,8 @@
 #include "load.h"
 #include "equ.h"
 
-int
-COS( LA_ALIST ) LA_DCL
-{
+pmlret_t
+COS( LA_ALIST ) {
+    (void) nargs;
     RETREAL( cos( LA_REAL(0) ) );
 }
