@@ -1,4 +1,4 @@
-/* $Id: delete.c,v 1.6 2003/06/08 18:59:59 phil Exp $ */
+/* $Id: delete.c,v 1.11 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SITBOL compatibility;
@@ -16,20 +16,28 @@
 #include <unistd.h>			/* unlink() */
 #endif /* HAVE_UNISTD_H defined */
 
+#include <stdlib.h>			/* for free() */
+
+#ifdef UNLINK_IN_STDIO_H		/* Windoze! */
+#include <stdio.h>
+#endif
+
 #include "h.h"
 #include "equ.h"
 #include "snotypes.h"
 #include "macros.h"
 #include "load.h"
 
-int
-DELETE( LA_ALIST ) LA_DCL
-{
-    char path[256];			/* XXX */
+pmlret_t
+DELETE( LA_ALIST ) {
+    char *path;
+    int ret;
 
-    getstring( LA_PTR(0), path, sizeof(path) );
-    if (unlink(path) < 0) {
+    (void) nargs;
+    path = mgetstring(LA_PTR(0));
+    ret = unlink(path);
+    free(path);
+    if (ret < 0)
 	RETFAIL;
-    }
     RETNULL;
 }
