@@ -1,4 +1,4 @@
-/* $Id: exit.c,v 1.7 2003/04/21 18:31:40 phil Exp $ */
+/* $Id: exit.c,v 1.11 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -15,6 +15,7 @@
 #endif /* HAVE_CONFIG_H defined */
 
 #include <stdio.h>			/* for lib.h */
+#include <stdlib.h>			/* for free() */
 
 #include "h.h"
 #include "snotypes.h"
@@ -24,16 +25,18 @@
 #include "equ.h"			/* datatypes I/S */
 #include "lib.h"			/* io_flushall(),execute() */
 
-int
-EXIT( LA_ALIST ) LA_DCL
-{
-    char buf[512];			/* XXX */
+pmlret_t
+EXIT( LA_ALIST ) {
+    char *str;
 
+    (void) retval;
+    (void) nargs;
     if (LA_TYPE(0) == S) {		/* EXIT("command") */
-	getstring( LA_PTR(0), buf, sizeof(buf));
+	str = mgetstring(LA_PTR(0));
 	io_flushall(0);			/* flush output buffers */
-	execute(buf);			/* should not return */
+	execute(str);			/* should not return */
 	/* ~sigh~ */
+	free(str);
 	RETFAIL;
     }
 
