@@ -1,4 +1,4 @@
-/* $Id: exp.c,v 1.8 2003/07/14 15:08:30 phil Exp $ */
+/* $Id: exp.c,v 1.12 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SNOBOL4+ compatibility;
@@ -18,11 +18,11 @@
 #include "load.h"
 #include "equ.h"
 
-int
-EXP( LA_ALIST ) LA_DCL
-{
+pmlret_t
+EXP( LA_ALIST ) {
     real_t ret = exp(LA_REAL(0));
-    if (!finite(ret))
+    (void) nargs;
+    if (!REAL_ISFINITE(ret))
 	RETFAIL;
     RETREAL(ret);
 }
