@@ -1,4 +1,4 @@
-/* $Id: findunit.c,v 1.5 2003/04/21 18:31:40 phil Exp $ */
+/* $Id: findunit.c,v 1.8 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * LOAD("IO_FINDUNIT()INTEGER")
@@ -17,11 +17,12 @@
 #include "equ.h"
 #include "lib.h"
 
-int
-IO_FINDUNIT( LA_ALIST ) LA_DCL
-{
+pmlret_t
+IO_FINDUNIT( LA_ALIST ) {
     int i;
 
+    (void) args;
+    (void) nargs;
     i = io_findunit();			/* from lib/io.c */
     if (i < 0) {
 	RETFAIL;
