@@ -1,4 +1,4 @@
-/* $Id: getenv.c,v 1.5 2002/02/16 00:58:04 phil Exp $ */
+/* $Id: getenv.c,v 1.9 2020-10-17 00:02:42 phil Exp $ */
 
 /*
  * Get an environment variable;  must be linked in (via pml.h)
@@ -22,6 +22,8 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
+#include <stdlib.h>			/* for free() */
+
 #include "h.h"
 #include "equ.h"
 #include "snotypes.h"
@@ -30,12 +32,12 @@
 
 extern char *getenv();
 
-int
-GETENV( LA_ALIST ) LA_DCL
-{
-    char buf[256];			/* XXX */
-    char *env;
+lret_t
+GETENV( LA_ALIST ) {
+    char *var, *val;
 
-    getstring(LA_PTR(0), buf, sizeof(buf) );
-    RETSTR(getenv(buf));
+    var = mgetstring(LA_PTR(0));
+    val = getenv(var);
+    free(var);
+    RETSTR(val);
 }
