@@ -1,4 +1,4 @@
-/* $Id: log.c,v 1.5 2003/04/21 18:04:19 phil Exp $ */
+/* $Id: log.c,v 1.8 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SNOBOL4+ compatibility;
@@ -18,8 +18,8 @@
 #include "load.h"
 #include "equ.h"
 
-int
-LOG( LA_ALIST ) LA_DCL
-{
+pmlret_t
+LOG( LA_ALIST ) {
+    (void) nargs;
     RETREAL( log( LA_REAL(0) ) );
 }
