@@ -1,4 +1,4 @@
-/* $Id: ord.c,v 1.4 2003/04/21 18:07:04 phil Exp $ */
+/* $Id: ord.c,v 1.7 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * LOAD("ORD(STRING)INTEGER")
@@ -18,9 +18,9 @@
 #include "load.h"
 #include "equ.h"
 
-int
-ORD( LA_ALIST ) LA_DCL
-{
+pmlret_t
+ORD( LA_ALIST ) {
+    (void) nargs;
     if (LA_PTR(0) == NULL || LA_STR_LEN(0) == 0)
 	RETFAIL;
     RETINT((unsigned char)*LA_STR_PTR(0));
