@@ -1,4 +1,4 @@
-/* $Id: rename.c,v 1.7 2004/09/12 08:39:00 phil Exp $ */
+/* $Id: rename.c,v 1.12 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SITBOL compatibility;
@@ -12,6 +12,7 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
+#include <stdlib.h>			/* for free() */
 #include <stdio.h>			/* rename */
 
 #include "h.h"
@@ -20,18 +21,21 @@
 #include "macros.h"
 #include "load.h"
 
-int
-RENAME( LA_ALIST ) LA_DCL
-{
-    char path1[1024];			/* XXX */
-    char path2[1024];			/* XXX */
+pmlret_t
+RENAME( LA_ALIST ) {
+    char *path1;
+    char *path2;
+    int ret;
 
-    getstring(LA_PTR(0), path1, sizeof(path1) );
-    getstring(LA_PTR(1), path2, sizeof(path2) );
+    (void) nargs;
+    path1 = mgetstring(LA_PTR(0));
+    path2 = mgetstring(LA_PTR(1));
 
     /* ANSI C, POSIX.1 and XPG3 have rename() */
-    if (rename(path2, path1) < 0) {
+    ret = rename(path2, path1);
+    free(path1);
+    free(path2);
+    if (ret < 0)
 	RETFAIL;
-    }
     RETNULL;
 }
