@@ -1,4 +1,4 @@
-/* $Id: sin.c,v 1.6 2003/04/21 18:04:19 phil Exp $ */
+/* $Id: sin.c,v 1.9 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -18,8 +18,8 @@
 #include "load.h"
 #include "equ.h"
 
-int
-SIN( LA_ALIST ) LA_DCL
-{
+pmlret_t
+SIN( LA_ALIST ) {
+    (void) nargs;
     RETREAL( sin( LA_REAL(0) ) );
 }
