@@ -1,4 +1,4 @@
-/* $Id: sqrt.c,v 1.7 2003/04/21 18:04:19 phil Exp $ */
+/* $Id: sqrt.c,v 1.10 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -17,11 +17,11 @@
 #include "load.h"
 #include "equ.h"
 
-int
-SQRT( LA_ALIST ) LA_DCL
-{
+pmlret_t
+SQRT( LA_ALIST ) {
     real_t x;
 
+    (void) nargs;
     x = LA_REAL(0);
     if (x < 0) {
 	RETFAIL;
