@@ -1,4 +1,4 @@
-/* $Id: sset.c,v 1.6 2003/04/21 18:31:40 phil Exp $ */
+/* $Id: sset.c,v 1.9 2020-11-19 02:31:31 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -21,11 +21,11 @@
  * Returns;	scaled file position
  */
 
-int
-SSET( LA_ALIST ) LA_DCL
-{
+pmlret_t
+SSET( LA_ALIST ) {
     int_t unit, offset, whence, scale, oof;
 
+    (void) nargs;
     unit = LA_INT(0);
     offset = LA_INT(1);
     whence = LA_INT(2);
