@@ -1,12 +1,10 @@
-/* $Id: system.c,v 1.5 2003/07/04 20:01:09 phil Exp $ */
+/* $Id: system.c,v 1.7 2020-10-17 00:02:42 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H defined */
 
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>			/* system() */
-#endif /* HAVE_STDLIB_H defined */
+#include <stdlib.h>			/* system(), free() */
 
 #include "h.h"
 #include "equ.h"
@@ -21,10 +19,10 @@
  * Returns;	exit status
  */
 
-SYSTEM( LA_ALIST ) LA_DCL
-{
-    char cmd[256];			/* XXX */
-
-    getstring( LA_PTR(0), cmd, sizeof(cmd) );
-    RETINT( system(cmd) );
+lret_t
+SYSTEM( LA_ALIST ) {
+    char *cmd = getstring(LA_PTR(0));
+    int ret = system(cmd);
+    free(cmd);
+    RETINT(ret);
 }
