@@ -1,4 +1,4 @@
-/* $Id: tan.c,v 1.7 2003/07/14 15:08:30 phil Exp $ */
+/* $Id: tan.c,v 1.11 2020-11-19 02:31:31 phil Exp $ */
 
 /*
  * SPARC SPITBOL compatibility;
@@ -18,11 +18,11 @@
 #include "load.h"
 #include "equ.h"
 
-int
-TAN( LA_ALIST ) LA_DCL
-{
+pmlret_t
+TAN( LA_ALIST ) {
     real_t ret = tan(LA_REAL(0));
-    if (!finite(ret))
+    (void) nargs;
+    if (!REAL_ISFINITE(ret))
 	RETFAIL;
     RETREAL(ret);
 }
