@@ -1,4 +1,4 @@
-/* $Id: top.c,v 1.10 2003/05/30 02:34:30 phil Exp $ */
+/* $Id: top.c,v 1.11 2020-09-27 19:45:56 phil Exp $ */
 
 #ifndef STATIC_TOP
 #ifdef HAVE_CONFIG_H
@@ -18,9 +18,7 @@
 /*# define DEBUG_TOP*/
 
 STATIC_TOP void
-top( d1, d2, d3 )
-   register struct descr *d1, *d2, *d3;
-{
+top(struct descr *d1, struct descr *d2, struct descr *d3) {
    int_t a;
 
    a = D_A(d3);
