@@ -1,4 +1,4 @@
-/* $Id: exists.c,v 1.3 2003/04/24 16:38:01 phil Exp $ */
+/* $Id: exists.c,v 1.4 2020-09-29 05:02:39 phil Exp $ */
 
 /*
  * File existance check for VMS
@@ -19,9 +19,7 @@
 #include "lib.h"
 
 int
-exists(path)
-    char *path;
-{
+exists(char *path) {
     struct stat st;
 
     return stat(path, &st) >= 0;
