@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.6 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.7 2020-09-29 05:02:39 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -29,7 +29,7 @@
 #endif /* CLK_TCK not defined */
 
 real_t
-mstime() {
+mstime(void) {
     struct tbuffer tbuff;
 
     times(&tbuff);
