@@ -1,4 +1,4 @@
-/* $Id: osopen.c,v 1.2 2003/07/03 21:47:46 phil Exp $ */
+/* $Id: osopen.c,v 1.4 2020-09-29 05:02:39 phil Exp $ */
 
 /*
  * VMS open hook
@@ -16,15 +16,12 @@
 #include "str.h"			/* strcmp */
 
 int
-osdep_open(fname, mode, fpp)
-    const char *fname, *mode;
-    FILE **fpp;
-{
+osdep_open(const char *fname, const char *mode, FILE **fpp) {
     if (strcmp(fname, "/dev/tty") == 0) {
 	*fpp = fopen("TT:", mode);
 	return TRUE;			/* matched */
     }
-    if (strcmp(fname, "/dev/nul") == 0) {
+    if (strcmp(fname, "/dev/null") == 0) {
 	*fpp = fopen("NL:", mode);	/* NLA0:? */
 	return TRUE;			/* matched */
     }
