@@ -1,4 +1,4 @@
-/* $Id: term.c,v 1.7 2003/04/21 23:52:43 phil Exp $ */
+/* $Id: term.c,v 1.8 2020-09-29 05:02:39 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -16,6 +16,6 @@
  */
 
 FILE *
-term_input() {
+term_input(void) {
     return fopen("SYS$COMMAND:", "r");
 }
