@@ -1,4 +1,4 @@
-/* $Id: mstime.c,v 1.11 2003/04/21 22:57:39 phil Exp $ */
+/* $Id: mstime.c,v 1.14 2020-10-13 04:47:53 phil Exp $ */
 
 /* get user runtime on Win32 pb 12/22/97 */
 
@@ -13,10 +13,6 @@
 #include "snotypes.h"
 #include "lib.h"
 
-#ifdef NO_STATIC_VARS
-#include "vars.h"
-#endif /* NO_STATIC_VARS defined */
-
 /*
  * The FILETIME data structure contains two 32-bit values that combine to
  * form a 64-bit count of 100-nanosecond time units.
@@ -25,12 +21,11 @@
 /* divisor for low 32 */
 #define TICKSPERMS 10000.0
 
-/* multiplier for high 32; */
-#define HIGHMS 429496.0			/* (2**32)/TICKSPERMS */
+/* multiplier for high 32 (PLB 2020-09-19: was 429496.0) */
+#define HIGHMS 429496.7296	 /* (2**32)/TICKSPERMS (4.97 days!) */
 
 real_t
-mstime()
-{
+mstime(void) {
     FILETIME start, texit, kernel, user;
 
     /*
@@ -46,8 +41,7 @@ mstime()
 	 * so it doesn't track runtime!! Use time of day instead??
 	 * XXX just use ANSI clock() function???
 	 */
-#ifndef NO_STATIC_VARS
-	static FILETIME t0;
+	static VAR FILETIME t0;
 
 	if (t0.dwHighDateTime || t0.dwLowDateTime) {
 	    FILETIME t;
@@ -60,21 +54,5 @@ mstime()
 	    GetSystemTimeAsFileTime(&t0);
 	    return 0;
 	}
-#else  /* NO_STATIC_VARS defined */
-	FILETIME *t0p;
-	if (timevars) {
-	    FILETIME t;
-
-	    t0p = timevars;
-	    GetSystemTimeAsFileTime(&t);
-	    return ((t.dwHighDateTime - t0p->dwHighDateTime) * HIGHMS +
-		    (t.dwLowDateTime - t0p->dwLowDateTime) / TICKSPERMS);
-	}
-	else {
-	    timevars = t0p = malloc(sizeof(FILETIME));
-	    GetSystemTimeAsFileTime(t0p);
-	    return 0;
-	}
-#endif /* NO_STATIC_VARS defined */
     }
 }
