@@ -1,4 +1,4 @@
-/* $Id: osopen.c,v 1.3 2010/05/30 04:38:33 phil Exp $ */
+/* $Id: osopen.c,v 1.6 2020-09-27 22:22:44 phil Exp $ */
 
 /*
  * Win32 open hook
@@ -16,18 +16,22 @@
 #include "lib.h"
 
 int
-osdep_open(fname, mode, fpp)
-    const char *fname, *mode;
-    FILE **fpp;
-{
+osdep_open(const char *fname, const char *mode, FILE **fpp) {
     if (strcmp(fname, "/dev/tty") == 0) {
 	*fpp = fopen("CON", mode);
+#ifdef _IONBF
+	if (*fpp) {
+	    // no line buffering on windoze, so turn of buffering.
+	    // setbuf(*fpp, NULL) should do the same thing as this, and
+	    // might be more portable, but is now deprecated.
+	    setvbuf(*fpp, (char *)NULL, _IONBF, 0);
+	}
+#endif
 	return TRUE;			/* matched */
     }
-    if (strcmp(fname, "/dev/nul") == 0) {
+    if (strcmp(fname, "/dev/null") == 0) {
 	*fpp = fopen("NUL", mode);
 	return TRUE;			/* matched */
     }
     return FALSE;			/* no match */
 }
-
