@@ -1,4 +1,4 @@
-/* $Id: term.c,v 1.1 2003/06/17 01:29:33 phil Exp $ */
+/* $Id: term.c,v 1.2 2020-09-27 22:18:09 phil Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -16,6 +16,6 @@
  */
 
 FILE *
-term_input() {
+term_input(void) {
     return fopen("CONIN$", "r");
 }
