@@ -18,13 +18,13 @@ else
     fi
 fi
 
-ARGS="$*"
-echo "testing $SNOBOL $ARGS"
-export SNOBOL ARGS
+IARGS="$*"
+echo "testing $SNOBOL $IARGS"
+echo 'search path:' `$SNOBOL $IARGS -z`
+export SNOBOL
 
 # test list
 TESTS=tests.in
-echo "tests from $TESTS"
 
 # function (ie; test or ref)
 FUNC=test
@@ -35,13 +35,28 @@ FAIL=0
 # optional fail count
 OPTFAIL=0
 
-while read TYPE PROG; do
+if [ "$BLOCKS" ]; then
+	TESTS="$TESTS blocks.in"
+fi
+echo "tests from $TESTS"
+cat $TESTS | while read TYPE PROG; do
 	if [ "$TYPE" = '#' ]; then
 		continue
 	fi
-	echo ${PROG}:
-	# XXX cope here with comments, empty lines?
-	./${FUNC}.${TYPE}.sh $PROG
+	(
+	    ARGS="$IARGS -b"
+	    echo ${PROG}:
+	    for X in ${PROG}; do
+		case "$X" in
+		-*) ARGS="$ARGS $X";;
+		*=*) eval $X; export `echo $X | sed 's/=.*$//'`;;
+		*) PROG=$X; break;;
+		esac
+	    done
+	    export ARGS
+	    # XXX cope here with comments, empty lines?
+	    ./${FUNC}.${TYPE}.sh $PROG
+	)
 	case $? in
 	0)
 		PASS=`expr $PASS + 1`
@@ -59,7 +74,7 @@ while read TYPE PROG; do
 		## out to top level, so just exit from here!
 		exit $FAIL
 	esac
-done < $TESTS
+done
 
 # would love to output counts, but "while" loop runs in a subshell (due
 # to input redirection?), so variable changes made inside loop are not
